==> foundation-0.0.52.tgz: package/Default/IWG/World/Load/LoaderBase.js <==
export class IWGLoadBase {
    gen;
    settings = {
        doSearchUpdate: true,
        doWorldGenUpdate: true,
        doSaveUpate: true,
        timeout: 500,
    };
    constructor(gen) {
        this.gen = gen;
    }
    _getTotalTasks(types) {
        let total = 0;
        for (const type of types) {
            this.gen.tasks[type].forEach((_) => {
                total += _.queue.length;
            });
        }
        return total;
    }
    _getTotalInProgress(types) {
        let total = 0;
        for (const type of types) {
            this.gen.tasks[type].forEach((_) => {
                total += _.waitingFor;
            });
        }
        return total;
    }
    _waitTillAllTasksAreDone(type, onCheck = () => { }) {
        return new Promise((resolve) => {
            const searchInte = setInterval(() => {
                if (this.settings.doSearchUpdate)
                    this.gen.searchUpdate();
                if (this.settings.doWorldGenUpdate)
                    this.gen.worldGenUpdate(Infinity);
                if (this.settings.doSaveUpate)
                    this.gen.saveUpdate(Infinity);
            }, 10);
            setTimeout(() => {
                const tasksInte = setInterval(() => {
                    onCheck(this.gen);
                    if (this._getTotalTasks(type) == 0 &&
                        this._getTotalInProgress(type) == 0) {
                        clearInterval(searchInte);
                        clearInterval(tasksInte);
                        resolve(true);
                    }
                }, this.settings.timeout);
            });
        });
    }
}

==> foundation-0.0.53.tgz: package/Default/IWG/World/Load/LoaderBase.js <==
export class IWGLoadBase {
    gen;
    settings = {
        doWorldGenUpdate: true,
        doSaveUpate: true,
        doBuildUpdate: false,
        timeout: 500,
    };
    constructor(gen) {
        this.gen = gen;
    }
    _getTotalTasks(types) {
        let total = 0;
        for (const type of types) {
            this.gen.tasks[type].forEach((_) => {
                total += _.queue.length;
            });
        }
        return total;
    }
    _getTotalInProgress(types) {
        let total = 0;
        for (const type of types) {
            this.gen.tasks[type].forEach((_) => {
                total += _.waitingFor;
            });
        }
        return total;
    }
    _waitTillAllTasksAreDone(type, onCheck = () => { }) {
        return new Promise((resolve) => {
            const searchInte = setInterval(() => {
                if (this.settings.doWorldGenUpdate) {
                    this.gen.worldGenUpdate(Infinity);
                    this.gen.generateUpdate();
                }
                if (this.settings.doBuildUpdate) {
                    this.gen.renderTaskUpdate(Infinity);
                    this.gen.renderUpdate();
                }
                if (this.settings.doSaveUpate)
                    this.gen.saveUpdate(Infinity);
            }, 10);
            setTimeout(() => {
                const tasksInte = setInterval(() => {
                    onCheck(this.gen);
                    if (this._getTotalTasks(type) == 0 &&
                        this._getTotalInProgress(type) == 0) {
                        clearInterval(searchInte);
                        clearInterval(tasksInte);
                        resolve(true);
                    }
                }, this.settings.timeout);
            });
        });
    }
}
